@@ -6,7 +6,7 @@
 #' @param osm_ids vector of OSM identifiers (`c(00000, 11111, 22222)`).
 #' @param type vector of the type of the OSM type associated to each `osm_ids`.
 #'   Possible values are node ("N"), way ("W") or relation ("R"). If a single
-#'   value is provided it would be recycled.#'
+#'   value is provided it would be recycled.
 #' @inheritParams geo_lite
 #'
 #' @details
@@ -30,7 +30,7 @@
 #' @export
 
 geo_address_lookup <- function(osm_ids,
-                               type,
+                               type = c("N", "W", "R"),
                                lat = "lat",
                                long = "lon",
                                full_results = FALSE,
