@@ -64,8 +64,6 @@ geo_amenity_sf <- function(bbox,
                            custom_query = list(),
                            points_only = TRUE,
                            strict = FALSE) {
-  amenity <- unique(amenity)
-
   # nocov start
 
   if (limit > 50) {
@@ -83,19 +81,42 @@ geo_amenity_sf <- function(bbox,
   all_res <- NULL
 
   for (i in seq_len(length(amenity))) {
-    res_single <- geo_amenity_sf_single(
-      bbox = bbox,
-      amenity = amenity[i],
-      limit,
-      full_results,
-      return_addresses,
-      verbose,
-      custom_query,
-      points_only
-    )
+    # Check if we have already launched the query
+    if (amenity[i] %in% all_res$query) {
+      if (verbose) {
+        message(
+          amenity[i],
+          " already cached.\n",
+          "Skipping download."
+        )
+      }
+
+      res_single <- dplyr::filter(
+        all_res,
+        .data$query == amenity[i],
+        .data$nmlite_first == 1
+      )
+      res_single$nmlite_first <- 0
+    } else {
+      res_single <- geo_amenity_sf_single(
+        bbox = bbox,
+        amenity = amenity[i],
+        limit,
+        full_results,
+        return_addresses,
+        verbose,
+        custom_query,
+        points_only
+      )
+      # Add index
+      res_single <- dplyr::bind_cols(res_single, nmlite_first = 1)
+    }
+
     all_res <- dplyr::bind_rows(all_res, res_single)
   }
 
+  all_res <- dplyr::select(all_res, -.data$nmlite_first)
+
   if (strict) {
     bbox_sf <- bbox_to_poly(bbox)
     strict <- sf::st_covered_by(all_res, bbox_sf, sparse = FALSE)
