@@ -41,4 +41,10 @@ test_that("Checking query", {
   expect_equal(nrow(geo_lite("Madrid",
     custom_query = list(extratags = 1)
   )), 1)
+
+  expect_equal(nrow(geo_lite(
+    c("Pentagon", "Pentagon"),
+    limit = 1,
+    verbose = TRUE
+  )), 2)
 })
